% This script runs the temporal 1D stability problem
%
% (c) Ardeshir Hanifi 2014
%
clear all
%% Numerical parameters
N = 200; % number of Cehebychev modes

%% Flow parameters
Re=1e4;
alpha=1;
beta=0.4;

%% Select the collocation nodes and set up derivative operator
M=2; % Highest order of derivative required
[y, D] = chebdif(N, 2);

%% Velocity profile corresponding to Plane Poiseuille Flow
U.u=1-y.^2;
U.uy=-2*y;
U.w=zeros(size(y)); % This field is required as the code is written for a 3D flow
U.wy=zeros(size(y)); % This field is required as the code is written for a 3D flow

%% Set up the eigenvalue problem
[A,B] = LNS_temp(U, D, alpha, beta, Re);

%% Solve the eigenvalue problem
[eigvec, eigval] = eig(A,B);
eigval=diag(eigval);

%% Plot spectrum and eigenvectors
header=strcat({'Re= '},{num2str(Re)},{', alpha= '},{num2str(alpha)},...
              {', beta= '},{num2str(beta)});
plot_LNS(eigval,eigvec,y,header)