% This script runs the temporal 1D stability code
%
% (c) Ardeshir Hanifi 2014
%
clear all
%% Numerical parameters
N = 200; % number of Cehebychev modes

%% Flow parameters
Re=1e4;
alpha=1;
beta=0.4;

%% Select the collocation nodes and set up derivative operator
M=4; % Highest order of derivative required
[y, D] = chebdif(N, M);

%% Velocity profile corresponding to Plane Poiseuille Flow
U.u=1-y.^2;
U.uy=-2*y;
U.uyy=-2+y*0;
%% Set up the eigenvalue problem
[A,B] = OS_temp(U, D, alpha, beta, Re);

%% Solve the eigenvalue problem
[eigvec, eigval] = eig(A,B);
eigval=diag(eigval);

%% Plot spectrum and eigenvectors
header=strcat({'Re= '},{num2str(Re)},{', alpha= '},{num2str(alpha)},...
              {', beta= '},{num2str(beta)});
plot_OS(eigval,eigvec,y,header)

